      SUBROUTINE RHOLMEN(RES,RV,RAPP,RW,RB,RTR,RA,RELRAP,FN,RN,RLWL,B,T,
     &                   CB,CWP,CM,GESCH,RHO,ZAEH,WS,SA,AT,ABL,HB,RLCB,
     &                   TRIM,EIPK2,CSTERN,XKS,DTUNEL,CBTO,RLZB,CP)
C 
C---------------------------------------------------------------------
C
C     Resistance computation following HOLTROP-MENNEN
C     Programmed at Institut fuer Schiffbau / University of Hamburg
C
C
C     Input parameters :  (REAL)
C
C     RLWL  : length in waterline [M]
C     B     : width [M]
C     T     : draft [M]
C     TRIM  : trim (Tfp-Tap) [M]
C     CB    : block coefficient based on RLWL
C     CWP   : waterplane coefficient 
C     CM    : coefficient of amidship 
C     ABL   : area of bulbous bow at FP (forward perpendicular) [M*M]
C     HB    : height of center of area of ABL [M]
C     SA    : wetted surface of all appendages [M*M]
C     EIPK2 : average form factor of appendages (1.3 < EIPK2 < 4.)
C             the following values are recommended:
C              rudder behind support       1.5 - 2.0
C              rudder behind stern         1.3 - 1.5
C              balanced rudder             2.8
C              shaft brackets              3.0
C              rudder support              1.5 - 2.0
C              shaft bearing               3.0
C              shaft bossing               2.0
C              shafts                      2.0 - 4.0
C              stabilsing fins             2.8
C              bilge keels                 1.4
C              
C          for several appendages, for each appendage the form factor and the wetted surface have to be input
C
C          
C     RLR   : length of the run [M] (here standard value taken)
C     RLCB  : LCB ahead of 0.5 RLWL [%RLWL]
C     GESCH : speed [M/S]
C     RHO   : density of(sea) water [kg/m**3]
C     TEMP  : temperature of sea water [C]
C     WS    : wetted surface [M*M] (here standard value taken)
C     CSTERN: coefficient for shape of aftbody
C             -10 for extreme V-section;  +10 for extreme U-section
C     AT    : immersed transom area [M*M] at speed =0
C     XKS   : roughness constant for ship hull; standard=150.*E-6
C     DTUNEL: diameter of bow thruster [M]
C     CBTO  : coefficient for KOEFFIZIENT FUER BUGSTRAHLWIDERSTAND; ( 0.003 BIS 0.012 )
C
C
C     Output parameters :  (REAL)
C
C     RES   :Resistance in [KN]
C     RV    :Viscous resistance 
C     RA    :added resistance
C     RAPP  :resistance of appendages
C     RWNOB :wave resistance w/o bulbous bow correction
C     RW    :wave resistance with bulbous bow correction
C     RB    :bulbous bow resistance
C     RTR   :SPIEGELWIDERSTAND
C     RELRAP:resistance of opening bow thruster
C     CVA   :viscous flow resistance coefficient (1+K)*CF+CA
C     GUT   :logical variable:
C             GUT=.TRUE.   : resistance computed
C             GUT=.FALSE.  : resistance was not computed
C
C
C  Range of input data:
C        3.9 < LWL/B < 9.5
C        0.55 < CP < 0.85
C        FN < 0.40
C
C  Range of validity incl extrapolation: 
C        FN < 0.40            
C        3.5 < LWL/B < 10.45  
C        0.5 < CP < 0.93      
C
C     LITERATURE:  HOLTROP / MENNEN, INT. SHIPB. PROGR. 1982,P. 166
C
C---------------------------------------------------------------------
C.....ratios L/B, B/T, B/L, T/L and Cp
      RLZB=RLWL/B
      BZT=B/T
      CP=CB/CM
      BZL=B/RLWL
      TZL=T/RLWL
C.....Reynolds and Froude numbers
      RN=GESCH*RLWL/ZAEH
      FN=GESCH/SQRT(9.81*RLWL)
C
      VERDR=RLWL*B*T*CB
      VZL=VERDR**(1./3.)/RLWL
      RL3ZV=1./VZL**3.
C
      IF(ABS(XKS).LE.0.00000001) XKS=150.E-6
C
      RB=0.
      RV=0.
      RA=0.
      RAPP=0.
      RWNOB=0.
      RW=0.
      RTR=0.
      RELRAP=0.
C
      RLR=(1-CP+0.06*CP*RLCB/(4.*CP-1.))*RLWL
C.....RLR   : length of the run [M] 

      C13=1.+0.003*CSTERN

      C12=48.2*(TZL-0.02)**2.078+0.479948
      IF(TZL.LT.0.02) C12=0.479948
      IF(TZL.GT.0.05) C12=TZL**0.2228446
      EIPK=C13*(0.93+C12*(B/RLR)**0.92497*(0.95-CP)**(-0.521448)
     *    *(1.-CP+0.0225*RLCB)**0.6906)

      IF(RN.EQ.0.0) CF=0.0
      IF(RN.NE.0.0) CF=0.075/(ALOG10(RN)-2.)**2

      SK=0.5*RHO*GESCH**2
C.....viscous resistance
      RV = EIPK *CF*WS*SK
C.....appendage resistance
      RAPP=EIPK2*CF*SA*SK
C.....resistance of opening bow thruster
      RELRAP=RHO*(GESCH**2)*3.1416*(DTUNEL**2)*CBTO*2.
      WURABT=SQRT(ABL)
      TF=T+0.5*TRIM
 
      C15=-1.69385+(1./VZL-8.0)/2.36
      IF(RL3ZV.LT.512.) C15=-1.69385
      IF(RL3ZV.GT.1727.) C15=0.0
      RM2=C15*(CP**2)*EXP(-0.1*FN**(-2.))

      RLAM=1.446*CP-0.03*RLWL/B
      IF(RLWL/B.GT.12.) RLAM=1.446*CP-0.36

      C16=8.07981*CP-13.8673*CP**2+6.984388*CP**3.
      IF(CP.GT.0.8) C16=1.73014-0.7067*CP

      RM1=0.0140407*RLWL/T-1.75254*VZL-4.79323*BZL-C16
      C5=1.-0.8*AT/(B*T*CM)
      C3=0.56*ABL**1.5/(B*T*(0.31*WURABT+TF-HB))
      C2=EXP(-1.89*SQRT(C3))
      RIE=1.+89.*EXP(-(RLZB)**0.80856*(1.-CWP)**0.30484*(1.-CP-0.0225
     &   *RLCB)**0.6367*(RLR/B)**0.34574*(100./RL3ZV)**0.16302)

      C7=BZL
      IF(BZL.LT.0.11) C7=0.229577*(BZL)**(1./3.)
      IF(BZL.GT.0.25) C7=0.5-0.0625*RLZB
      C1=2223105.*C7**3.78613*(T/B)**1.07961*(90.-RIE)**(-1.37565)
C.....wave resistance w/o bulbous bow correction
      RWNOB=C1*C5*VERDR*RHO*9.81*EXP(RM1*FN**(-0.9)
     &     +RM2*COS(RLAM*FN**(-2.)))
C.....wave resistance with bulbous bow correction
      RW=RWNOB*C2
      IF(WURABT.LT.0.1) GOTO 10
      PB=0.56*WURABT/(TF-1.5*HB)
      RI=TF-HB-0.25*WURABT
      FNI=GESCH/SQRT(9.81*RI+0.15*GESCH**2)
C.....bulbous bow resistance
      RB=0.11*EXP(-3./PB**2)*FNI**3*WURABT**3*RHO*9.81/(1.+FNI**2)
   10 C4=AMIN1(0.04,TF/RLWL)

      CA=0.006*(RLWL+100.)**(-0.16)-0.00205
     &  +0.003*SQRT(RLWL/7.5)*CB**4*C2*(0.04-C4)
      DCA=(0.105*XKS**(1./3.)-0.005579)/RLWL**(1./3.)
      IF(XKS.LE.150.E-6) DCA=0.0
      CA=CA+DCA
C.....viscous resistance coefficient (1+K)*CF+CA
      CVA=EIPK*CF+CA
C.....added resistance
      RA=CA*SK*(WS+SA)
      IF(AT.LT.0.1) GOTO 7
      FNT=GESCH/SQRT(2*9.81*AT/(B+B*CWP))
      C6=0.2*(1.-0.2*FNT)
      IF(FNT.GE.5.) C6=0.0
C.....transom resistance
      RTR=SK*AT*C6
C.....total resistance
    7 RES=RV+RAPP+RW+RB+RTR+RA+RELRAP
C.....conversion from N to KN
      RES=RES/1000.0
      RV=RV/1000.0
      RAPP=RAPP/1000.0
      RW=RW/1000.0
      RB=RB/1000.0
      RTR=RTR/1000.0
      RA=RA/1000.0
      RELRAP=RELRAP/1000.0
C
      END




