      SUBROUTINE SIMQIT(A,R,N,NMAX,SING,AV,DX,X)
C Iterative solution of a non-singular, real linear system of equations
C A X = R, where A, X and R are (n by n), (n by 1) and (n by 1) matrices,
C respectively. (n by c) means: n rows, c columns.

C Method: Incomplete Gauss elimination: Those matrix coefficients 
C the absolute 
C value of which exceeds the column pivot element times the value 
C AVERH are 
C eliminated before a Gauss-Seidel iteration with column pivoting 
C is applied. 
C If no convergence is encountered, another elimination step 
C is performed
C with half the previous value of AVERH. The starting value of 
C AVERH is AV.

C Parameter A (input; changed): Two-index array of size 1:NMAX >= n,
C 1: >= n + 2) containing the elements of the matrix A. FIRST INDEX 
C COUNTS COLUMNS, LAST INDEX COUNTS ROWS.
C Parameter R (input; changed): One-index array containing the elements 
C  of the   matrix R
C Parameter N (input): Number of unknowns
C Parameter NMAX (input): Maximum defined value of first index of A
C Parameter SING (input): Lower limit of absolute value of pivot
C elements. If
C     a division by an element the absolute value of which is smaller 
C     than SING
C     would be required, elimination is stopped with an error message 
C     indicating
C     the indices of those equations which are responsible for the 
C     difficulty.
C     It is recommended to generate the equation system such that 
C     maximum 
C     absolute values of the elements of A in each row and column do
C      not differ 
C     by orders of magnitude. Then, for SING a value of 10**-5 times 
C     that 
C     maximum absolute value may be recommended.
C Parameter AV (input): See above under method. Recommended value: 
C     sqrt(1/N).
C Parameter DX: The iteration stops if the maximum absolute change of 
C     any 
C     unknown within one iteration step is smaller than DX.
C Parameter X (input and result): array of size 1: >= n containing 
C     an estimated
C     solution when calling the subroutine (if no estimation is 
C     available, 0 is
C     recommended), and the solution vector X after return
      INTEGER IS, ITER, IZ, IZPIV, IZ1, N, NMAX
      REAL AA, AV, AVERH, ALIMIT, BMAX, DX, DXMAX, DXMAXV, SAVE, SING
      REAL A(NMAX,N+2), R(N), X(N)
C Initial values for R and (n+2)nd column of A (equation numbers)
      DO 1 IS=1,N
1     A(IS,N+2)=IS+0.5
      DO 2 IZ=1,N
      DO 2 IS=1,N
2     R(IZ)=R(IZ)-X(IS)*A(IS,IZ)
      AVERH=AV*1.4
      iter=1
3     AVERH=AVERH/1.4
      iter=iter+1
C     For all rows
      DO 50 IZ = 1,N
C     Search for pivot element 
	 BMAX=0.
	 DO 5 IZ1 = IZ,N
	    IF(ABS(A(IZ,IZ1)).GT.BMAX)THEN
	       IZPIV = IZ1
	       BMAX = ABS(A(IZ,IZ1))
	    ENDIF
5        CONTINUE
	 IF (BMAX.LT.SING) THEN
	    WRITE(*,*)'Equation system is singular: Bmax=',BMAX
	    STOP
	 ENDIF
C        Exchange of pivot and IZ rows; normalization of pivot row
	 ALIMIT = BMAX*AVERH
	 BMAX=SIGN(BMAX,A(IZ,IZPIV))
	 IF (IZPIV.EQ.IZ) THEN
	    DO 9 IS=1,N
9           A(IS,IZ)=A(IS,IZ)/BMAX
	 ELSE
	    DO 10 IS = 1,N
	    SAVE=A(IS,IZPIV)
	    A(IS,IZPIV)=A(IS,IZ)
10          A(IS,IZ)=SAVE/BMAX
	 ENDIF
	 SAVE=A(IZPIV,N+2)
	 A(IZPIV,N+2)=A(IZ,N+2)
	 A(IZ,N+2)=SAVE
	 SAVE=R(IZPIV)
	 R(IZPIV)=R(IZ)
	 R(IZ)=SAVE/BMAX
C     Elimination of large coefficients
	 DO 20 IZ1=IZ+1,N
	    AA=-A(IZ,IZ1)
	    IF (ABS(AA).GT.ALIMIT) THEN
	       DO 15 IS=1,N
15             A(IS,IZ1)=A(IS,IZ1)+AA*A(IS,IZ)
	       R(IZ1)   =R(IZ1)   +AA*R(IZ)
	    ENDIF
20       CONTINUE
50    CONTINUE
C     Determination of changes of X stored in A(IZ,N+1)
      DXMAXV=1.E30
60    DXMAX=0
      DO 80 IZ=N,1,-1
	 A(IZ,N+1)=R(IZ)
	 DO 75 IS=IZ+1,N
75       A(IZ,N+1)=A(IZ,N+1)-A(IS,IZ)*A(IS,N+1)
	 DXMAX=MAX(DXMAX,ABS(A(IZ,N+1)))
80    X(IZ)=X(IZ)+A(IZ,N+1)
      IF(DXMAX.LT.DX)RETURN
C     Update of absolute value vector R
      DO 100 IZ=1,N
	 R(IZ)=0.
	 DO 100 IS=1,IZ-1
100   R(IZ)=R(IZ)-A(IS,N+1)*A(IS,IZ)
      IF(DXMAX.GT.0.8*DXMAXV) GOTO 3
      DXMAXV=DXMAX
      GOTO 60
      END
